import { expect, expectAsync, tap } from '@pushrocks/tapbundle';
import * as qenv from '@pushrocks/qenv';

const testQenv = new qenv.Qenv('./', './.nogit/');

import * as tink from '../ts/index';

let tinkTestAccount: tink.TinkAccount;

tap.preTask('should delete existing users', async () => {
  const preTinkAccount = tinkTestAccount = new tink.TinkAccount(
    testQenv.getEnvVarOnDemand('TINK_CLIENT_ID'),
    testQenv.getEnvVarOnDemand('TINK_CLIENT_SECRET')
  );
  expect(tinkTestAccount).toBeInstanceOf(tink.TinkAccount);
  const tinkUser = new tink.TinkUser(preTinkAccount, null, 'user_1234_abc');
  await tinkUser.delete();
})

tap.test('should create a valid tink account', async () => {
  tinkTestAccount = new tink.TinkAccount(
    testQenv.getEnvVarOnDemand('TINK_CLIENT_ID'),
    testQenv.getEnvVarOnDemand('TINK_CLIENT_SECRET')
  );
  expect(tinkTestAccount).toBeInstanceOf(tink.TinkAccount);
});

tap.test('should report tink as healthy', async () => {
  await expectAsync(tinkTestAccount.getTinkHealthyBoolean()).toBeTrue();
});

tap.test('should create a valid request', async () => {
  await tinkTestAccount.createTinkUser("user_1234_abc");
})

tap.start();
